@@ -1,13 +1,13 @@
 from setuptools import setup
 
 setup(
-    version='1.0',
+    version='1.3',
     name='qweborf',
     author="Salvo 'LtWorf' Tomaselli",
     author_email='tiposchi@tiscali.it',
     maintainer="Salvo 'LtWorf' Tomaselli",
     maintainer_email='tiposchi@tiscali.it',
-    url='https://ltworf.github.io/weborf/',
+    url='https://ltworf.codeberg.page/weborf/',
     license='GPL3',
     packages=('qweborf',),
     )
